@@ -2,16 +2,13 @@
 import logging
 
 __author__ = "DataWhys"
-__version__ = "0.3.2"
+__version__ = "0.4.0"
 
 # Configuration variables
 auth_enabled = True
 api_key = None
-api_secret = None
-api_token = None
 
 api_base = "https://api.datawhys.ai/"
-auth0_domain = "mb-production.us.auth0.com"
 
 verify_ssl_certs = True
 proxy = None
