@@ -1,19 +1,6 @@
-from auth0.v3.authentication import GetToken
 from requests.packages.urllib3.fields import RequestField
 from requests.packages.urllib3.filepost import encode_multipart_formdata
 
-import datawhys
-
-
-def get_token(key, secret, auth0_domain=None) -> str:
-    domain = auth0_domain or datawhys.auth0_domain
-
-    gt = GetToken(domain)
-    resp = gt.client_credentials(key, secret, "https://api.mondobrain.com/")
-    access = resp.get("access_token", None)
-
-    return access
-
 
 def encode_multipart(params: dict):
     new_fields = []
