@@ -24,6 +24,10 @@ class Solver:
 
     Parameters
     ----------
+    timeout: int (optional)
+        A positive integer that denotes the timeout to apply to the Solver loop.
+        Defaults to API value.
+
     min_size_frac: float (optional), default=0.2
         Value between 0.0 and 1.0 that defines the minimum number of points needed
         for a valid rule discovered by the DataWhys solver.
@@ -43,7 +47,6 @@ class Solver:
     Using the solver to find a rule
 
     >>> dw.api_key = "<API KEY>"
-    >>> dw.api_secret = "<API SECRET>"
     >>> solver = dw.Solver()
     >>> solver.fit(dwf_explorable, dwf_outcome)
     >>> solver.rule
@@ -60,8 +63,9 @@ class Solver:
     """
 
     def __init__(
-        self, min_size_frac=0.2, min_purity=0.0, max_cycles=90,
+        self, timeout=None, min_size_frac=0.2, min_purity=0.0, max_cycles=90,
     ):
+        self.timeout = timeout
         self.min_size_frac = min_size_frac
         self.min_purity = min_purity
         self.max_cycles = max_cycles
@@ -70,14 +74,6 @@ class Solver:
     def _is_one_dim_solve(explorable_vars):
         return explorable_vars.shape[1] == 1
 
-    @staticmethod
-    def _get_timeout(n_points, n_features, lg_coefficient=3.5, max_cycles=90):
-
-        lg_timeout = int(lg_coefficient * np.sqrt(n_points * n_features / 2))
-        min_timeout = np.minimum(lg_timeout, max_cycles)
-
-        return int(np.maximum(1, min_timeout))
-
     @staticmethod
     def _get_dataset_buffer(df: pd.DataFrame):
         buffer = BytesIO()
@@ -120,18 +116,14 @@ class Solver:
                 )
             )
 
-        # Solve Behavior isn't supported by file endpoint yet
-        timeout = self._get_timeout(
-            edf.shape[0], edf.shape[1] - 1, max_cycles=self.max_cycles
-        )
-
         buf = Solver._get_dataset_buffer(edf)
         task = dw.api.solve_start_file(
             outcome=outcome_encoded,
             target=target_encoded,
             data=buf,
-            timeout=timeout,
+            timeout=self.timeout,
             min_size_frac=self.min_size_frac,
+            max_cycles=self.max_cycles,
         )
         result = dw.api.solve_result(id=task["id"])
 
@@ -166,6 +158,17 @@ class Solver:
 
         return rule_decoded, sample_stats, score, discarded_rules
 
+    @property
+    def timeout(self):
+        return self._timeout
+
+    @timeout.setter
+    def timeout(self, value):
+        if value is not None and value <= 0:
+            raise ValueError("'timeout' must be greater than 0.")
+
+        self._timeout = value
+
     @property
     def max_cycles(self):
         return self._max_cycles
@@ -454,14 +457,12 @@ class Solver:
         edf, _ = utilities.sample_if_needed(edf, None, outcome_encoded)
 
         data = json.loads(edf.to_json(orient="records"))
-        timeout = self._get_timeout(
-            edf.shape[0], edf.shape[1] - 1, max_cycles=self.max_cycles
-        )
         options = {
             "outcome": outcome_encoded,
             "data": data,
             "min_size_frac": self.min_size_frac,
-            "timeout": timeout,
+            "timeout": self.timeout,
+            "max_cycles": self.max_cycles,
         }
 
         exp.explore(options)
